import {
  InvalidQuery
} from "./chunk-XIRHVLVQ.js";

// src/enums/sort_direction.ts
var SortDirection = {
  Ascending: "asc",
  Descending: "desc"
};

// src/exceptions/invalid_direction.ts
import { Exception } from "@adonisjs/core/exceptions";
var InvalidDirection = class _InvalidDirection extends Exception {
  static make(sort) {
    return new _InvalidDirection(
      `The direction should be either \`${SortDirection.Descending}\` or \`${SortDirection.Ascending}\` ${sort} given`
    );
  }
};

// src/sorts/sorts_callback.ts
var SortsCallback = class {
  constructor(_callback) {
    this._callback = _callback;
  }
  handle(query, descending, property) {
    this._callback(query, descending, property);
  }
};

// src/sorts/sorts_field.ts
var SortsField = class {
  handle(query, descending, property) {
    void query.orderBy(property, descending ? "desc" : "asc");
  }
};

// src/allowed_sort.ts
var AllowedSort = class _AllowedSort {
  static parseSortDirection(name) {
    return name.startsWith("-") ? SortDirection.Descending : SortDirection.Ascending;
  }
  static field(name, internalName) {
    return new _AllowedSort(name, new SortsField(), internalName);
  }
  static custom(name, sortClass, internalName) {
    return new _AllowedSort(name, sortClass, internalName);
  }
  static callback(name, callback, internalName) {
    return new _AllowedSort(name, new SortsCallback(callback), internalName);
  }
  defaultDirection;
  internalName;
  name;
  sortClass;
  constructor(name, sortClass, internalName) {
    this.name = name.replace(/^-+/, "");
    this.defaultDirection = _AllowedSort.parseSortDirection(name);
    this.sortClass = sortClass;
    this.internalName = internalName ?? this.name;
  }
  sort(query, descending) {
    descending = descending ?? this.defaultDirection === SortDirection.Descending;
    this.sortClass.handle(query, descending, this.internalName);
  }
  getName() {
    return this.name;
  }
  isSort(sortName) {
    return this.name === sortName;
  }
  getInternalName() {
    return this.internalName;
  }
  setDefaultDirection(defaultDirection) {
    if (![SortDirection.Ascending, SortDirection.Descending].includes(defaultDirection)) {
      throw InvalidDirection.make(defaultDirection);
    }
    this.defaultDirection = defaultDirection;
    return this;
  }
};

// src/exceptions/invalid_sort_query.ts
import { ResponseStatus } from "@adonisjs/core/http";
var InvalidSortQuery = class _InvalidSortQuery extends InvalidQuery {
  constructor(unknownSorts, allowedSorts) {
    const notAllowed = unknownSorts.join(", ");
    const allowed = allowedSorts.join(", ");
    const message = `Requested sort(s) \`${notAllowed}\` is not allowed. Allowed sort(s) are \`${allowed}\``;
    super(message, { status: ResponseStatus.BadRequest });
    this.unknownSorts = unknownSorts;
    this.allowedSorts = allowedSorts;
  }
  static sortsNotAllowed(unknownSorts, allowedSorts) {
    return new _InvalidSortQuery(unknownSorts, allowedSorts);
  }
};

export {
  SortDirection,
  InvalidDirection,
  SortsCallback,
  SortsField,
  AllowedSort,
  InvalidSortQuery
};
//# sourceMappingURL=chunk-3ITWUZL5.js.map