import {
  InvalidQuery
} from "./chunk-XIRHVLVQ.js";

// src/includes/included_callback.ts
var IncludedCallback = class {
  constructor(callback) {
    this.callback = callback;
  }
  handle(query, include) {
    void query.preload(include, this.callback);
  }
};

// src/includes/included_count.ts
import app from "@adonisjs/core/services/app";
var IncludedCount = class {
  handle(query, count) {
    const suffix = app.config.get("apiquery.countSuffix", "Count");
    const relation = count.endsWith(suffix) ? count.slice(0, -suffix.length) : count;
    void query.withCount(relation);
  }
};

// src/includes/included_relationship.ts
import { Collection } from "collect.js";
var IncludedRelationship = class {
  static getIndividualRelationshipPathsFromInclude(include) {
    const originalInclude = new Collection(include.split("."));
    return originalInclude.reduce((includes, relationship) => {
      const includesArray = includes ?? new Collection();
      if (includesArray.isEmpty()) {
        return includesArray.push(relationship);
      }
      return includesArray.push(`${includes.last()}.${relationship}`);
    }, new Collection());
  }
  getRequestedFieldsForRelatedTable;
  handle(query, relationship) {
    const relatedTables = relationship.split(".");
    if (relatedTables.length === 0) {
      return;
    }
    const [relation, ...rest] = relatedTables;
    if (!query.model.$hasRelation(relation)) {
      return;
    }
    void query.preload(relation, (subQuery) => {
      if (this.getRequestedFieldsForRelatedTable !== void 0) {
        const fields = this.getRequestedFieldsForRelatedTable(relation);
        if (fields.length > 0) {
          void subQuery.select(fields);
        }
      }
      this.buildNestedQuery(rest, subQuery, relation);
    });
  }
  buildNestedQuery(relatedTables, subQuery, parent = "") {
    if (relatedTables.length === 0) {
      return;
    }
    const [relation, ...rest] = relatedTables;
    if (!subQuery.model.$hasRelation(relation)) {
      return;
    }
    void subQuery.preload(relation, (nestedQuery) => {
      const fullRelationName = parent === "" ? relation : `${parent}.${relation}`;
      if (this.getRequestedFieldsForRelatedTable !== void 0) {
        const fields = this.getRequestedFieldsForRelatedTable(fullRelationName);
        if (fields.length > 0) {
          void nestedQuery.select(fields);
        }
      }
      this.buildNestedQuery(rest, nestedQuery, fullRelationName);
    });
  }
};

// src/allowed_include.ts
import app2 from "@adonisjs/core/services/app";
import { Collection as Collection2 } from "collect.js";
var AllowedInclude = class _AllowedInclude {
  static relationship(name, internalName) {
    internalName = internalName ?? name;
    return IncludedRelationship.getIndividualRelationshipPathsFromInclude(internalName).zip(IncludedRelationship.getIndividualRelationshipPathsFromInclude(name).toArray()).reduce((includes, args) => {
      const [relationship, alias] = args;
      includes = includes.push(
        new _AllowedInclude(alias, new IncludedRelationship(), relationship)
      );
      if (!relationship.includes(".")) {
        const countSuffix = app2.config.get("apiquery.countSuffix", "Count");
        for (const countAllowedInclude of _AllowedInclude.count(
          `${alias}${countSuffix}`,
          `${relationship}${countSuffix}`
        )) {
          includes = includes.push(countAllowedInclude);
        }
      }
      return includes;
    }, new Collection2());
  }
  static count(name, internalName) {
    return new Collection2([new _AllowedInclude(name, new IncludedCount(), internalName)]);
  }
  static callback(name, callback, internalName) {
    return new Collection2([
      new _AllowedInclude(name, new IncludedCallback(callback), internalName)
    ]);
  }
  static custom(name, includeClass, internalName) {
    return new Collection2([new _AllowedInclude(name, includeClass, internalName)]);
  }
  internalName;
  name;
  includeClass;
  constructor(name, includeClass, internalName) {
    this.name = name;
    this.includeClass = includeClass;
    this.internalName = internalName ?? this.name;
  }
  include(query) {
    this.includeClass.handle(query, this.internalName);
  }
  getName() {
    return this.name;
  }
  isForInclude(includeName) {
    return this.name === includeName;
  }
};

// src/exceptions/invalid_include_query.ts
import { ResponseStatus } from "@adonisjs/core/http";
var InvalidIncludeQuery = class _InvalidIncludeQuery extends InvalidQuery {
  constructor(unknownIncludes, allowedIncludes) {
    const notAllowed = unknownIncludes.join(", ");
    let message = `Requested include(s) \`${notAllowed}\` are not allowed. `;
    if (allowedIncludes.length > 0) {
      const allowed = allowedIncludes.join(", ");
      message = `${message}Allowed include(s) are \`${allowed}\``;
    } else {
      message = `${message}There are no allowed includes`;
    }
    super(message, { status: ResponseStatus.BadRequest });
    this.unknownIncludes = unknownIncludes;
    this.allowedIncludes = allowedIncludes;
  }
  static includesNotAllowed(unknownIncludes, allowedIncludes) {
    return new _InvalidIncludeQuery(unknownIncludes, allowedIncludes);
  }
};

export {
  IncludedCallback,
  IncludedCount,
  IncludedRelationship,
  AllowedInclude,
  InvalidIncludeQuery
};
//# sourceMappingURL=chunk-IV3B5WO7.js.map