// src/api_query_builder_request.ts
import { HttpContext } from "@adonisjs/core/http";
import app from "@adonisjs/core/services/app";
import { Collection } from "collect.js";

// src/utils/helpers.ts
var substrReplace = (str, replace, start, length) => {
  if (start < 0) {
    start += str.length;
  }
  length = length ?? str.length;
  if (length < 0) {
    length = length + str.length - start;
  }
  return [
    str.slice(0, start),
    replace.slice(0, Math.max(0, length)),
    replace.slice(length),
    str.slice(start + length)
  ].join("");
};
var strBeforeLast = (subject, search) => {
  if (search === "") {
    return subject;
  }
  const pos = subject.lastIndexOf(search);
  if (pos === -1) {
    return subject;
  }
  return subject.slice(0, Math.max(0, pos));
};
var strAfterLast = (subject, search) => {
  if (search === "") {
    return subject;
  }
  const pos = subject.lastIndexOf(search);
  if (pos === -1) {
    return subject;
  }
  return subject.slice(pos + search.length);
};

// src/api_query_builder_request.ts
var ApiQueryBuilderRequest = class _ApiQueryBuilderRequest {
  static includesArrayValueDelimiter = ",";
  static appendsArrayValueDelimiter = ",";
  static fieldsArrayValueDelimiter = ",";
  static sortsArrayValueDelimiter = ",";
  static filterArrayValueDelimiter = ",";
  static setArrayValueDelimiter(delimiter) {
    this.includesArrayValueDelimiter = delimiter;
    this.appendsArrayValueDelimiter = delimiter;
    this.fieldsArrayValueDelimiter = delimiter;
    this.sortsArrayValueDelimiter = delimiter;
    this.filterArrayValueDelimiter = delimiter;
  }
  static setIncludesArrayValueDelimiter(includesArrayValueDelimiter) {
    this.includesArrayValueDelimiter = includesArrayValueDelimiter;
  }
  static setAppendsArrayValueDelimiter(appendsArrayValueDelimiter) {
    this.appendsArrayValueDelimiter = appendsArrayValueDelimiter;
  }
  static setFieldsArrayValueDelimiter(fieldsArrayValueDelimiter) {
    this.fieldsArrayValueDelimiter = fieldsArrayValueDelimiter;
  }
  static setSortsArrayValueDelimiter(sortsArrayValueDelimiter) {
    this.sortsArrayValueDelimiter = sortsArrayValueDelimiter;
  }
  static setFilterArrayValueDelimiter(filterArrayValueDelimiter) {
    this.filterArrayValueDelimiter = filterArrayValueDelimiter;
  }
  static getIncludesArrayValueDelimiter() {
    return this.includesArrayValueDelimiter;
  }
  static getAppendsArrayValueDelimiter() {
    return this.appendsArrayValueDelimiter;
  }
  static getFieldsArrayValueDelimiter() {
    return this.fieldsArrayValueDelimiter;
  }
  static getSortsArrayValueDelimiter() {
    return this.sortsArrayValueDelimiter;
  }
  static getFilterArrayValueDelimiter() {
    return this.filterArrayValueDelimiter;
  }
  static resetDelimiters() {
    this.includesArrayValueDelimiter = ",";
    this.appendsArrayValueDelimiter = ",";
    this.fieldsArrayValueDelimiter = ",";
    this.sortsArrayValueDelimiter = ",";
    this.filterArrayValueDelimiter = ",";
  }
  static fromRequest(request) {
    return new _ApiQueryBuilderRequest(request);
  }
  _request;
  constructor(request) {
    if (!request) {
      const ctx = HttpContext.getOrFail();
      request = ctx.request;
    }
    this._request = request;
  }
  includes() {
    const includeParameterName = app.config.get("apiquery.parameters.include", "include");
    let includeParts = this.getRequestData(includeParameterName, []);
    if (typeof includeParts === "string") {
      includeParts = includeParts.split(_ApiQueryBuilderRequest.getIncludesArrayValueDelimiter());
    }
    return new Collection(includeParts).filter();
  }
  appends() {
    const appendParameterName = app.config.get("apiquery.parameters.append", "append");
    let appendParts = this.getRequestData(appendParameterName, {});
    if (typeof appendParts === "string") {
      appendParts = appendParts.split(_ApiQueryBuilderRequest.getAppendsArrayValueDelimiter());
    }
    return new Collection(appendParts).filter();
  }
  fields() {
    const fieldsParameterName = app.config.get("apiquery.parameters.fields", "fields");
    const fieldsData = this.getRequestData(fieldsParameterName, {});
    const fieldsPerTable = new Collection(
      typeof fieldsData === "string" ? fieldsData.split(_ApiQueryBuilderRequest.getFieldsArrayValueDelimiter()) : fieldsData
    );
    if (fieldsPerTable.isEmpty()) {
      return new Collection();
    }
    const fields = {};
    fieldsPerTable.each((tableFields, model) => {
      if (!model || typeof model === "number") {
        model = typeof tableFields === "string" && tableFields.includes(".") ? strBeforeLast(tableFields, ".") : "_";
      }
      if (!fields[model]) {
        fields[model] = [];
      }
      if (typeof tableFields === "string") {
        tableFields = tableFields.split(_ApiQueryBuilderRequest.getFieldsArrayValueDelimiter()).map((field) => {
          return strAfterLast(field, ".");
        });
      }
      fields[model] = [...fields[model], ...tableFields];
    });
    return new Collection(fields);
  }
  sorts() {
    const sortParameterName = app.config.get("apiquery.parameters.sort", "sort");
    let sortParts = this.getRequestData(sortParameterName, []);
    if (typeof sortParts === "string") {
      sortParts = sortParts.split(_ApiQueryBuilderRequest.getSortsArrayValueDelimiter());
    }
    return new Collection(sortParts).filter();
  }
  filters() {
    const filterParameterName = app.config.get("apiquery.parameters.filter", "filter");
    const filterParts = this.getRequestData(filterParameterName, []);
    if (typeof filterParts === "string") {
      return new Collection();
    }
    const filters = new Collection(filterParts);
    return filters.map((value) => {
      return this.getFilterValue(value);
    });
  }
  getFilterValue(value) {
    if (value === void 0 || value === null) {
      return null;
    }
    if (value === "" || Array.isArray(value) && value.length === 0 || typeof value === "object" && Object.keys(value).length === 0) {
      return typeof value === "object" ? [] : value;
    }
    if (Array.isArray(value) || typeof value === "object") {
      return new Collection(value).map((valueValue) => {
        return this.getFilterValue(valueValue);
      }).all();
    }
    if (typeof value === "string" && value.includes(_ApiQueryBuilderRequest.getFilterArrayValueDelimiter())) {
      return value.split(_ApiQueryBuilderRequest.getFilterArrayValueDelimiter());
    }
    if (value === "true") {
      return true;
    }
    if (value === "false") {
      return false;
    }
    return value;
  }
  getRequestData(key, defaultValue) {
    return this._request.input(key, defaultValue);
  }
};

export {
  substrReplace,
  ApiQueryBuilderRequest
};
//# sourceMappingURL=chunk-MKQ3HMMA.js.map