import {
  AllowedFilter,
  InvalidFilterQuery
} from "./chunk-54HNQTDY.js";
import "./chunk-MKQ3HMMA.js";
import "./chunk-XIRHVLVQ.js";

// src/bindings/filters_query.ts
import collect from "collect.js";
var extendModelQueryBuilderWithFiltersQuery = function(builder, config) {
  const ensureAllFiltersExist = (self) => {
    if (config.disableInvalidFilterQueryException) {
      return;
    }
    const filterNames = self.$apiQueryBuilderRequest.filters().keys();
    const allowedFilterNames = self._allowedFilters.map((allowedFilter) => {
      return allowedFilter.getName();
    });
    const diff = filterNames.diff(allowedFilterNames);
    if (diff.isNotEmpty()) {
      throw InvalidFilterQuery.filtersNotAllowed(diff.all(), allowedFilterNames.all());
    }
  };
  const isFilterRequested = (self, allowedFilter) => {
    return self.$apiQueryBuilderRequest.filters().has(allowedFilter.getName());
  };
  const addRequestedFiltersToQuery = (query) => {
    query._allowedFilters.each((allowedFilter) => {
      if (isFilterRequested(query, allowedFilter)) {
        const value = query.$apiQueryBuilderRequest.filters().get(allowedFilter.getName());
        allowedFilter.filter(query, value);
        return;
      }
      if (allowedFilter.hasDefault()) {
        allowedFilter.filter(query, allowedFilter.getDefault());
      }
    });
  };
  builder.macro("allowedFilters", function(...filters) {
    const arrayFilters = Array.isArray(filters.at(0)) ? filters.at(0) : filters;
    this._allowedFilters = collect(arrayFilters).map((filter) => {
      if (filter instanceof AllowedFilter) {
        return filter;
      }
      return AllowedFilter.partial(filter);
    });
    ensureAllFiltersExist(this);
    addRequestedFiltersToQuery(this);
    return this;
  });
};
export {
  extendModelQueryBuilderWithFiltersQuery
};
//# sourceMappingURL=filters_query-LCFH2F2X.js.map