import {
  AllowedInclude,
  InvalidIncludeQuery
} from "./chunk-IV3B5WO7.js";
import "./chunk-XIRHVLVQ.js";

// src/bindings/includes_query.ts
import { Collection } from "collect.js";
var extendModelQueryBuilderWithIncludesQuery = function(builder, config) {
  const ensureAllIncludesExist = (self) => {
    if (config.disableInvalidIncludesQueryException) {
      return;
    }
    const includes = self.$apiQueryBuilderRequest.includes();
    const allowedIncludeNames = self._allowedIncludes.map((allowedInclude) => {
      return allowedInclude.getName();
    });
    const diff = includes.diff(allowedIncludeNames);
    if (diff.isNotEmpty()) {
      throw InvalidIncludeQuery.includesNotAllowed(diff.all(), allowedIncludeNames.all());
    }
  };
  const findInclude = (self, include) => {
    return self._allowedIncludes.first((included) => included.isForInclude(include));
  };
  const filterNonExistingIncludes = (self) => {
    const includes = self.$apiQueryBuilderRequest.includes();
    if (!config.disableInvalidIncludesQueryException) {
      return includes;
    }
    return includes.filter((include) => !findInclude(self, include));
  };
  const addIncludesToQuery = (self, includes) => {
    includes.each((include) => {
      const allowedInclude = findInclude(self, include);
      allowedInclude?.include(self);
    });
  };
  builder.macro("allowedIncludes", function(...includes) {
    const arrayIncludes = Array.isArray(includes.at(0)) ? includes.at(0) : includes;
    this._allowedIncludes = new Collection(arrayIncludes).reject((include) => typeof include === "string" && include.length === 0).reduce((result, include) => {
      if (include instanceof Collection) {
        for (const allowedInclude of include) {
          result = result.push(allowedInclude);
        }
        return result;
      }
      if (include.endsWith(config.countSuffix)) {
        for (const allowedInclude of AllowedInclude.count(include)) {
          result = result.push(allowedInclude);
        }
        return result;
      }
      for (const allowedInclude of AllowedInclude.relationship(include)) {
        result = result.push(allowedInclude);
      }
      return result;
    }, new Collection()).unique((allowedInclude) => {
      return allowedInclude.getName();
    });
    ensureAllIncludesExist(this);
    const resultIncludes = filterNonExistingIncludes(this);
    addIncludesToQuery(this, resultIncludes);
    return this;
  });
};
export {
  extendModelQueryBuilderWithIncludesQuery
};
//# sourceMappingURL=includes_query-PVONWQMC.js.map