import {
  AllowedSort,
  InvalidDirection,
  InvalidSortQuery,
  SortDirection,
  SortsCallback,
  SortsField
} from "./chunk-3ITWUZL5.js";
import {
  AllowedFilter,
  FilterOperator,
  FiltersBeginWithStrict,
  FiltersCallback,
  FiltersEndsWithStrict,
  FiltersExact,
  FiltersOperator,
  FiltersPartial,
  FiltersTrashed,
  InvalidFilterQuery
} from "./chunk-54HNQTDY.js";
import {
  ApiQueryBuilderRequest
} from "./chunk-MKQ3HMMA.js";
import {
  AllowedInclude,
  IncludedCallback,
  IncludedCount,
  IncludedRelationship,
  InvalidIncludeQuery
} from "./chunk-IV3B5WO7.js";
import {
  InvalidQuery
} from "./chunk-XIRHVLVQ.js";

// stubs/main.ts
import path from "node:path";
import { fileURLToPath } from "node:url";
var stubsRoot = path.dirname(fileURLToPath(import.meta.url));

// configure.ts
var configure = async (command) => {
  const codemods = await command.createCodemods();
  await codemods.updateRcFile((rcFile) => {
    rcFile.addProvider("@eienjs/adonisjs-api-query/api_query_provider");
  });
  await codemods.makeUsingStub(stubsRoot, "config.stub", {});
};

// src/define_config.ts
import { configProvider } from "@adonisjs/core";
var defineConfig = function(config) {
  return configProvider.create(async (_) => {
    return {
      parameters: {
        include: config.parameters?.include ?? "include",
        filter: config.parameters?.filter ?? "filter",
        sort: config.parameters?.sort ?? "sort",
        fields: config.parameters?.fields ?? "fields",
        append: config.parameters?.append ?? "append"
      },
      countSuffix: config.countSuffix ?? "Count",
      existsSuffix: config.existsSuffix ?? "Exists",
      disableInvalidFilterQueryException: config.disableInvalidFilterQueryException ?? false,
      disableInvalidSortQueryException: config.disableInvalidSortQueryException ?? false,
      disableInvalidIncludesQueryException: config.disableInvalidIncludesQueryException ?? false,
      convertRelationNamesToSnakeCasePlural: config.convertRelationNamesToSnakeCasePlural ?? false,
      convertRelationTableNameStrategy: config.convertRelationTableNameStrategy ?? false,
      convertFieldNamesToSnakeCase: config.convertFieldNamesToSnakeCase ?? false
    };
  });
};

// src/exceptions/allowed_fields_must_be_called_before_allowed_includes.ts
import { Exception } from "@adonisjs/core/exceptions";
var AllowedFieldsMustBeCalledBeforeAllowedIncludes = class extends Exception {
  static code;
  static status;
  constructor() {
    super("The QueryBuilder's `allowedFields` method must be called before the `allowedIncludes` method");
  }
};

// src/exceptions/invalid_append_query.ts
import { ResponseStatus } from "@adonisjs/core/http";
var InvalidAppendQuery = class _InvalidAppendQuery extends InvalidQuery {
  constructor(appendsNotAllowed, allowedAppends) {
    const notAllowed = appendsNotAllowed.join(", ");
    const allowed = allowedAppends.join(", ");
    const message = `Requested append(s) \`${notAllowed}\` are not allowed. Allowed append(s) are \`${allowed}\``;
    super(message, { status: ResponseStatus.BadRequest });
  }
  static appendsNotAllowed(appendsNotAllowed, allowedAppends) {
    return new _InvalidAppendQuery(appendsNotAllowed, allowedAppends);
  }
};

// src/exceptions/invalid_filter_value.ts
import { Exception as Exception2 } from "@adonisjs/core/exceptions";
var InvalidFilterValue = class _InvalidFilterValue extends Exception2 {
  static make(value) {
    return new _InvalidFilterValue(`Filter value \`${value}\` is invalid`);
  }
};

// src/exceptions/unknown_included_fields_query.ts
import { ResponseStatus as ResponseStatus2 } from "@adonisjs/core/http";
var UnknownIncludedFieldsQuery = class extends InvalidQuery {
  unknownFields;
  constructor(unknownFields) {
    const notAllowed = unknownFields.join(", ");
    const message = [
      `Requested field(s) \`${notAllowed}\` are not allowed (yet). `,
      "If you want to allow these fields, please make sure to call the QueryBuilder's `allowedFields` method before the `allowedIncludes` method"
    ].join("");
    super(message, { status: ResponseStatus2.BadRequest });
    this.unknownFields = unknownFields;
  }
};

// index.ts
export * from "collect.js";
export {
  AllowedFieldsMustBeCalledBeforeAllowedIncludes,
  AllowedFilter,
  AllowedInclude,
  AllowedSort,
  ApiQueryBuilderRequest,
  FilterOperator,
  FiltersBeginWithStrict,
  FiltersCallback,
  FiltersEndsWithStrict,
  FiltersExact,
  FiltersOperator,
  FiltersPartial,
  FiltersTrashed,
  IncludedCallback,
  IncludedCount,
  IncludedRelationship,
  InvalidAppendQuery,
  InvalidDirection,
  InvalidFilterQuery,
  InvalidFilterValue,
  InvalidIncludeQuery,
  InvalidQuery,
  InvalidSortQuery,
  SortDirection,
  SortsCallback,
  SortsField,
  UnknownIncludedFieldsQuery,
  configure,
  defineConfig,
  stubsRoot
};
//# sourceMappingURL=index.js.map