// providers/api_query_provider.ts
import { configProvider } from "@adonisjs/core";
import { RuntimeException } from "@adonisjs/core/exceptions";
import { ModelQueryBuilder } from "@adonisjs/lucid/orm";
var ApiQueryProvider = class {
  constructor(app) {
    this.app = app;
  }
  async boot() {
    const { extendModelQueryBuilderWithRequest } = await import("../api_query_request-QXOB4BN6.js");
    const { extendModelQueryBuilderWithSortsQuery } = await import("../sorts_query-NJTC5UXX.js");
    const { extendModelQueryBuilderWithFiltersQuery } = await import("../filters_query-LCFH2F2X.js");
    const { extendModelQueryBuilderWithIncludesQuery } = await import("../includes_query-PVONWQMC.js");
    const apiQueryConfigProvider = this.app.config.get("apiquery");
    const config = await configProvider.resolve(this.app, apiQueryConfigProvider);
    if (!config) {
      throw new RuntimeException(
        'Invalid "config/apiquery.ts" file. Make sure you are using the "defineConfig" method'
      );
    }
    extendModelQueryBuilderWithRequest(ModelQueryBuilder);
    extendModelQueryBuilderWithSortsQuery(ModelQueryBuilder, config);
    extendModelQueryBuilderWithFiltersQuery(ModelQueryBuilder, config);
    extendModelQueryBuilderWithIncludesQuery(ModelQueryBuilder, config);
  }
};
export {
  ApiQueryProvider as default
};
//# sourceMappingURL=api_query_provider.js.map