import {
  AllowedSort,
  InvalidSortQuery
} from "./chunk-3ITWUZL5.js";
import "./chunk-XIRHVLVQ.js";

// src/bindings/sorts_query.ts
import { collect } from "collect.js";
var extendModelQueryBuilderWithSortsQuery = function(builder, config) {
  const ensureAllSortsExist = (self) => {
    if (config.disableInvalidSortQueryException) {
      return;
    }
    const requestedSortNames = self.$apiQueryBuilderRequest.sorts().map((sort) => sort.replace(/^-+/, ""));
    const allowedSortNames = self._allowedSorts.map((sort) => sort.getName());
    const unknownSort = requestedSortNames.diff(allowedSortNames);
    if (unknownSort.isNotEmpty()) {
      throw InvalidSortQuery.sortsNotAllowed(unknownSort.all(), allowedSortNames.all());
    }
  };
  const findSort = (self, property) => {
    return self._allowedSorts.first((sort) => sort.isSort(property));
  };
  const addRequestedSortsToQuery = (self) => {
    self.$apiQueryBuilderRequest.sorts().each((property) => {
      const descending = property.startsWith("-");
      const key = property.replace(/^-+/, "");
      const sort = findSort(self, key);
      sort?.sort(self, descending);
    });
  };
  builder.macro("allowedSorts", function(...sorts) {
    const arraySorts = Array.isArray(sorts.at(0)) ? sorts.at(0) : sorts;
    this._allowedSorts = collect(arraySorts).map((sort) => {
      if (sort instanceof AllowedSort) {
        return sort;
      }
      return AllowedSort.field(sort.replace(/^-+/, ""));
    });
    ensureAllSortsExist(this);
    addRequestedSortsToQuery(this);
    return this;
  });
  builder.macro("defaultSort", function(...sorts) {
    if (this.$apiQueryBuilderRequest.sorts().isNotEmpty()) {
      return this;
    }
    const arraySorts = Array.isArray(sorts.at(0)) ? sorts.at(0) : sorts;
    collect(arraySorts).map((sort) => {
      if (sort instanceof AllowedSort) {
        return sort;
      }
      return AllowedSort.field(sort);
    }).each((sort) => {
      sort.sort(this);
    });
    return this;
  });
};
export {
  extendModelQueryBuilderWithSortsQuery
};
//# sourceMappingURL=sorts_query-NJTC5UXX.js.map